@@ -24,13 +24,18 @@ def serializer(schema=None, many=False):
     def factory(func):
         @wraps(func)
         def decorator(*args, **kwargs):
-
+            
+            old_vars= func.__wrapped__.__code__.co_varnames
+            is_function_with_validated_data = old_vars.__contains__('validated_data')
+                
             appended_kws = kwargs.pop('appended_kws', None)
 
             try:
                 client_data = dict()
 
-                if request.json:
+                content_type = request.headers.get('Content-Type')
+                if (content_type == 'application/json'):
+                    # if the request have json payload, the user need to send the Content-Type as application/json
                     client_data = request.json
                 elif request.form:
                     client_data = request.form.to_dict()
@@ -56,8 +61,8 @@ def serializer(schema=None, many=False):
                 raise AppValidationError(e.messages)
 
             if result:
-                kwargs.update(dict(validated_data=result))
-
+                if is_function_with_validated_data:
+                    kwargs.update(dict(validated_data=result))
             # if schema and request.method == "GET":
             try:
                 result = func(*args, **kwargs)
