@@ -43,4 +43,4 @@ def send_notification_message(
         },
     }
     app.logger.debug(data)
-    Producer().send_topic(topic=Topics.INTERNAL_NOTIFICATION_MESSAGE, datajson=data)
+    Producer().send_topic(topic=Topics.INTERNAL_NOTIFICATION_MESSAGE.value, datajson=data)
